@@ -7,12 +7,9 @@
 #ifndef DELEGATERECYCLER_H
 #define DELEGATERECYCLER_H
 
+#include <QPointer>
 #include <QQuickItem>
 #include <QVariant>
-#include <QPointer>
-
-
-class DelegateCache;
 
 class DelegateRecyclerAttached : public QObject
 {
@@ -20,30 +17,27 @@ class DelegateRecyclerAttached : public QObject
 
 public:
     DelegateRecyclerAttached(QObject *parent = nullptr);
-    ~DelegateRecyclerAttached();
-
-
+    ~DelegateRecyclerAttached() override;
 
 Q_SIGNALS:
     void pooled();
     void reused();
-
-
 };
 
 /**
- * This class may be used as a delegate of a ListView or a GridView in the case
- * the intended delegate is a bit heavy, with many objects inside.
+ * This class may be used as a delegate of a QtQuick.ListView or a QtQuick.GridView
+ * in the case the intended delegate is a bit heavy, with many objects inside.
  * This will ensure the delegate instances will be put back in a common pool after
  * destruction, so when scrolling a big list, the delegates from old delete items will
  * be taken from the pool and reused, minimizing the need of instantiating new objects
  * and deleting old ones. It ensures scrolling of lists with heavy delegates is
  * smoother and helps with memory fragmentations as well.
  *
- * NOTE: CardListView and CardGridView are already using this recycler, so do NOT use it
- * as a delegate for those 2 views.
- * Also, do NOT use this with a Repeater.
- * @since 2.4
+ * @note org::kde::kirigami::CardsListView and org::kde::kirigami::CardsGridView
+ * are already using this recycler, so do NOT use it as a delegate for those 2 views.
+ * Also, do NOT use this with a QtQuick.Repeater.
+ *
+ * @since org.kde.kirigami 2.4
  */
 class DelegateRecycler : public QQuickItem
 {
@@ -51,8 +45,10 @@ class DelegateRecycler : public QQuickItem
 
     /**
      * The Component the actual delegates will be built from.
-     * Note: the component may not be a child of this object, therefore it can't be
+     *
+     * @note the component may not be a child of this object, therefore it can't be
      * declared inside the DelegateRecycler declaration.
+     *
      * The DelegateRecycler will not take ownership of the delegate Component, so it's up
      * to the caller to delete it (usually with the normal child/parent relationship)
      */
@@ -60,8 +56,7 @@ class DelegateRecycler : public QQuickItem
 
 public:
     DelegateRecycler(QQuickItem *parent = nullptr);
-    ~DelegateRecycler();
-
+    ~DelegateRecycler() override;
 
     QQmlComponent *sourceComponent() const;
     void setSourceComponent(QQmlComponent *component);
@@ -70,7 +65,11 @@ public:
     static DelegateRecyclerAttached *qmlAttachedProperties(QObject *object);
 
 protected:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#else
+    void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#endif
     void focusInEvent(QFocusEvent *event) override;
 
     void updateHints();
