@@ -31,6 +31,9 @@
 
 #include <QClipboard>
 #include <QGuiApplication>
+#if defined(Q_OS_ANDROID)
+#include <QResource>
+#endif
 #include <QQmlContext>
 #include <QQuickItem>
 #include <QQuickStyle>
@@ -93,11 +96,14 @@ QUrl KirigamiPlugin::componentUrl(const QString &fileName) const
 
 using SingletonCreationFunction = QObject *(*)(QQmlEngine *, QJSEngine *);
 
-template<typename T>
+template<class T>
 inline SingletonCreationFunction singleton()
 {
-    return [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return new T;
+    static_assert(std::is_base_of<QObject, T>::value);
+    return [](QQmlEngine *engine, QJSEngine *) -> QObject * {
+        auto x = new T;
+        x->setParent(engine);
+        return x;
     };
 }
 
@@ -114,6 +120,8 @@ void KirigamiPlugin::registerTypes(const char *uri)
     if (QIcon::themeName().isEmpty() && !qEnvironmentVariableIsSet("XDG_CURRENT_DESKTOP")) {
         QIcon::setThemeSearchPaths({Kirigami::StyleSelector::resolveFilePath(QStringLiteral(".")), QStringLiteral(":/icons")});
         QIcon::setThemeName(QStringLiteral("breeze-internal"));
+    } else {
+        QIcon::setFallbackSearchPaths(QIcon::fallbackSearchPaths() << Kirigami::StyleSelector::resolveFilePath(QStringLiteral("icons")));
     }
 
     qmlRegisterSingletonType<Settings>(uri, 2, 0, "Settings", [](QQmlEngine *e, QJSEngine *) -> QObject * {
@@ -358,3 +366,4 @@ void KirigamiPlugin::registerTypes(QQmlEngine* engine)
 #endif
 
 #include "kirigamiplugin.moc"
+#include "moc_kirigamiplugin.cpp"
