@@ -87,10 +87,10 @@ void StyleSelector::setBaseUrl(const QUrl &baseUrl)
 
 QString StyleSelector::resolveFilePath(const QString &path)
 {
-#if defined(Q_OS_ANDROID)
+#if defined(KIRIGAMI_BUILD_TYPE_STATIC)
+    return QStringLiteral(":/qt-project.org/imports/org/kde/kirigami.2/") + path;
+#elif defined(Q_OS_ANDROID)
     return QStringLiteral(":/android_rcc_bundle/qml/org/kde/kirigami.2/") + path;
-#elif defined(KIRIGAMI_BUILD_TYPE_STATIC)
-    return QStringLiteral(":/org/kde/kirigami.2/") + path;
 #else
     if (s_baseUrl.isValid()) {
         return s_baseUrl.toLocalFile() + QLatin1Char('/') + path;
@@ -102,10 +102,10 @@ QString StyleSelector::resolveFilePath(const QString &path)
 
 QString StyleSelector::resolveFileUrl(const QString &path)
 {
-#if defined(Q_OS_ANDROID)
+#if defined(KIRIGAMI_BUILD_TYPE_STATIC)
+    return QStringLiteral("qrc:/qt-project.org/imports/org/kde/kirigami.2/") + path;
+#elif defined(Q_OS_ANDROID)
     return QStringLiteral("qrc:/android_rcc_bundle/qml/org/kde/kirigami.2/") + path;
-#elif defined(KIRIGAMI_BUILD_TYPE_STATIC)
-    return QStringLiteral("qrc:/org/kde/kirigami.2/") + path;
 #else
     return s_baseUrl.toString() + QLatin1Char('/') + path;
 #endif
